	****************************************************************************
	*******************	Investment Climate Unit - ETIIC		********************
	*******************	Creation date: September, 10 2024	********************
	*******************	Last version: September, 16 2024	********************
	*******************	Project: Reproducibility Green		********************
	*******************	File: Main							********************	
	****************************************************************************
	
	
	****************************************************************************
	********************* green_incentive_classification ***********************
	****************************************************************************

* log using 		"$root/descr_stat_greendirty.log", replace

import excel "$raw_data\World Bank CIT Incentives Database - Streamlined data by incentive.xlsx", firstrow clear


********************************************************************************
*                  1) Defining green and greening incentives                   *
********************************************************************************

// Separate definitions for 'green' and 'greening' incentives.
// Green sector incentives:  Conditioned on certain environmental sectors
// Green process incentives: Satisfy climate condition and/or a keyword search 
//                           for environment-based words but are not conditioned
//                           on specific environmental sectors
// If both green and greening conditions are fulfilled, then consider as green

***Defining GREEN SECTOR-ORIENTED INCENTIVES
/* Green sector-oriented incentives must have a condition that includes specific
sectors relating to environmental sustainability (drawn from the EU taxonomy for
sustainable activities):
	1. ISIC code E. Water supply; sewerage, waste management and remediation 
	activities.
	2. Non-ISIC "own categorized" sectors "renewable energy generation" and 
	"environmental protection."
If both green sector-oriented and green process-oriented conditions are 
fulfilled, then the incentive is classified as a green sector-oriented incentive. 
These incentives can also be conditioned on other non-environmental sectors as 
long as not all sectors are eligible. */


gen d_add_green=0

replace d_add_green=1 if strpos(isic_letter,"RENEWABLE")>0 
replace d_add_green=1 if  strpos(isic_letter,"ENVIRONMENTAL")>0

gen     Isic_1letter = substr(isic_letter,1,1)

replace Isic_1letter = "Environmental" if strpos(isic_letter, "ENVIRONMENTAL") > 0 
replace Isic_1letter = "AGRO-PROCESSING" if strpos(isic_letter, "AGRO") > 0 
replace Isic_1letter = "Industrial" if strpos(isic_letter, "INDUSTRIAL") > 0 
replace Isic_1letter = "Renewable" if strpos(isic_letter, "RENEWABLE") > 0 
replace Isic_1letter = "Outsourcing" if strpos(isic_letter, "Outsourcing") > 0 
replace Isic_1letter = "Services" if strpos(isic_letter, "SERVICES") > 0 
replace Isic_1letter = "ICT" if strpos(isic_letter, "ICT") > 0 
replace Isic_1letter = "Tourism" if strpos(isic_letter, "TOURISM") > 0 


//Look through isic_sub* to see whether any other sub industries might need to be included. 
fre isic_sub*, all

// isic_sub1-8: nothing explicitly sustainable/environmental found

/* ISIC Chapter E encompasses sectors related to Water Supply; Sewerage, Waste Management and Remediation Activities.
Division 36: Water collection, treatment, and supply
Division 37: Sewerage
Division 38: Waste collection, treatment, and disposal activities; materials recovery
Division 39: Remediation activities and other waste management services */

replace d_add_green=1 if Isic_1letter=="E"
* Sector "38" is under Chapter E, but including more.
replace d_add_green=1 if strpos(isic_2d, "38") > 0 


/* The ISIC system covers sectors that can be classified as green under ISIC, but needs complementary information to confirm.

The ISIC system provides a framework for classifying economic activities into specific categories, which can be aligned with the EU Taxonomy's green sectors. Below is a general mapping of the green sectors to ISIC codes:

Renewable Energy

ISIC Code 3510: Electric power generation, transmission, and distribution (specifically renewable energy generation)
Energy Efficiency

ISIC Code 4321: Electrical installation (for energy-efficient systems like smart grids)
ISIC Code 7110: Architectural and engineering activities and related technical consultancy (for energy efficiency projects in buildings)
Manufacture of Low-Carbon Technologies

ISIC Code 2910: Manufacture of motor vehicles (for electric vehicles)
ISIC Code 2395: Manufacture of articles of concrete, cement, and plaster (for sustainable construction materials)
Sustainable Water and Wastewater Management

ISIC Code 3600: Water collection, treatment, and supply
ISIC Code 3700: Sewerage
Waste Management

ISIC Code 3811: Collection of non-hazardous waste
ISIC Code 3821: Treatment and disposal of non-hazardous waste
ISIC Code 3830: Materials recovery
Sustainable Agriculture and Forestry

ISIC Code 0111: Growing of cereals (except rice), leguminous crops, and oil seeds (for organic farming)
ISIC Code 0210: Silviculture and other forestry activities
Sustainable Transport

ISIC Code 4921: Urban and suburban passenger land transport (public transport systems)
ISIC Code 3091: Manufacture of motorcycles (for electric bicycles)
ISIC Code 4911: Passenger rail transport, interurban
Green Buildings

ISIC Code 4100: Construction of buildings (for energy-efficient and low-carbon buildings)
Circular Economy

ISIC Code 3830: Materials recovery (related to recycling and waste recovery activities)
ISIC Code 3900: Remediation activities and other waste management services (for activities supporting circular economy practices)
Protection and Restoration of Biodiversity

ISIC Code 0210: Silviculture and other forestry activities (for conservation and reforestation projects)
ISIC Code 0146: Raising of swine/pigs (for biodiversity-friendly farming practices)
This mapping provides a general guide to how the green sectors under the EU Taxonomy can be associated with ISIC codes. The specific classification might vary depending on the detailed activity within each sector.*/


***Defining GREEN PROCESS-ORIENTED INCENTIVES
/* Green process-oriented incentives are identified on the basis of fulfilling 
either one of two conditions in the Corporate Income Tax Incentives Database:

	1. An explicit environmental condition: Reflects an explicit 
	climate/environmental/green purpose stated in the law or title of the 
	incentive. These conditions are identified manually.
	2. A keyword search followed by a qualitative (manual) verification for 
	relevance. Key words include: solar, wind, hydro, renewable, biofuel, 
	recycl, eco-, ecol, green, emission, environment, organic, pollution, 
	carbon, CO2, conservation, geothermal, electric car.

These incentives should not be conditioned on specific sectors relating to 
environmental sustainability. That is, if both green sector and green process 
conditions are fulfilled, then the incentive is considered to be a 
sector-oriented incentive, not a process-oriented incentive. */


gen 	d_add_greening_1  = 	 strpos(cond_desc, "solar") > 0 
gen 	d_add_greening_2  = 	 strpos(cond_desc, "wind" ) > 0 
replace d_add_greening_2  = 0 if strpos(cond_desc, "other than wind" ) > 0 
replace d_add_greening_2  = 0 if strpos(cond_desc, "windmill industry)") >0 
gen 	d_add_greening_3  = 	 strpos(cond_desc, "hydro" ) > 0 
gen 	d_add_greening_4  = 	 strpos(cond_desc, "renewable") > 0 
replace	d_add_greening_4  = 1 if strpos(cond_desc, "Renewable") > 0 
gen 	d_add_greening_5  = 	 strpos(cond_desc, "biofuel") > 0 
replace	d_add_greening_5  = 1 if strpos(cond_desc, "bio-fuel") > 0 
replace	d_add_greening_5  = 1 if strpos(cond_desc, "Biofuel") > 0 
replace d_add_greening_5  = 0 if strpos(cond_desc, "excluding additionally biofuel")>0 
gen 	d_add_greening_6  = 	 strpos(cond_desc, "recycl") > 0 
replace	d_add_greening_6  = 1 if strpos(cond_desc, "Recycl") > 0 
gen 	d_add_greening_7  = 	 strpos(cond_desc, "eco-") > 0 
replace	d_add_greening_7  = 1 if strpos(cond_desc, "ecol") > 0 
gen 	d_add_greening_8  = 	 strpos(cond_desc, "green") > 0 
replace d_add_greening_8  = 0 if strpos(cond_desc, "greenfield") > 0
gen 	d_add_greening_9  =  	 strpos(cond_desc, "emission") > 0 
gen 	d_add_greening_10 = 	 strpos(cond_desc, "environment") > 0 
gen 	d_add_greening_11 = 	 strpos(cond_desc, "organic") > 0 
gen 	d_add_greening_12 = 	 strpos(cond_desc, "pollution") > 0 
gen 	d_add_greening_13 = 	 strpos(cond_desc, "carbon") > 0 
replace	d_add_greening_13 = 1 if strpos(cond_desc, "CO2") > 0 
gen 	d_add_greening_14 = 	 strpos(cond_desc, "conservation") > 0 
gen 	d_add_greening_15 = 	 strpos(cond_desc, "geothermal") > 0 
gen 	d_add_greening_16 = 	 strpos(cond_desc, "electric car" ) > 0 


/* explicit environmental condition: Reflects an explicit climate/environmental/
green purpose stated in the law or title of the incentive. These conditions are 
identified manually:                                                          */

gen		d_add_greening_17 = 1 if inlist(climate_cond,1,2)

gen 	d_add_greening = 0

forvalues j = 1/17{
	replace d_add_greening=1 if d_add_greening_`j'==1
}

/* If both green sector-oriented and green process-oriented conditions are 
fulfilled, then the incentive is classified as a green sector-oriented incentive. 
These incentives can also be conditioned on other non-environmental sectors as 
long as not all sectors are eligible.*/

replace d_add_greening = 0 if d_add_greening == 1 & d_add_green == 1 


** Defining INCENTIVES FOR POLLUTING/ENVIRONMENTALLY DEGRADING SECTORS
/* This type of incentive must have an eligibility condition for a "polluting"
sector/activity:
1. A "polluting" activity, such as "stumping and clearing of lands"
2. A "polluting" sector (sectors defined by ISIC codes):
	B. Mining and quarrying; 05-Mining of coal and lignite; 06-Extraction of 
	crude petroleum and natural gas; 07-Mining of metal ores; 08-Other mining 
	and quarrying; 09-Mining support service activities
	C.19-Manufacture of coke and refined petroleum products; 20–Manufacture of 
	chemicals and chemical products; 22–Manufacture of rubber and plastics 
	products; 2394-Manufacture of cement, lime and plaster; 2395-Manufacture of 
	articles of concrete, cement and plaster; 241-Manufacture of basic iron and 
	steel
	D. Electricity; gas, steam and air conditioning supply; 35-Electricity, gas, 
	steam and air conditioning supply
The incentives must also not satisfy a green sector-oriented or green process-oriented condition. */


***create a dummy for incentives provided for dirty/polluting sectors/activities
gen d_dirty_polluting_ti=0
tab isic_letter

*** Chapters
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "B") > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "D") > 0 & d_add_green==0 & d_add_greening==0

*** Two digits
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "05")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "06")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "07")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "08")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "09")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "19")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "20")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "22")     > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_2d, "35")     > 0 & d_add_green==0 & d_add_greening==0

*** Three digits
replace d_dirty_polluting_ti=1 if strpos(isic_3d, "241")    > 0 & d_add_green==0 & d_add_greening==0

*** Four digits
replace d_dirty_polluting_ti=1 if strpos(isic_4d, "2394")   > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(isic_4d, "2395")   > 0 & d_add_green==0 & d_add_greening==0


*** Expanding polluting manufacturing
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "C") > 0 & inlist(isic_sub_cond2 ,"only") & strpos(isic_2d, "19")   > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "C") > 0 & inlist(isic_sub_cond2 ,"only") & strpos(isic_2d, "20")   > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "C") > 0 & inlist(isic_sub_cond2 ,"only") & strpos(isic_2d, "22")   > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "C") > 0 & inlist(isic_sub_cond2 ,"only") & strpos(isic_3d, "241")  > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "C") > 0 & inlist(isic_sub_cond2 ,"only") & strpos(isic_2d, "2394") > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(Isic_1letter, "C") > 0 & inlist(isic_sub_cond2 ,"only") & strpos(isic_2d, "2395") > 0 & d_add_green==0 & d_add_greening==0

replace d_dirty_polluting_ti=1 if strpos(cond_desc, "stumping") 		 > 0 & d_add_green==0 & d_add_greening==0
replace d_dirty_polluting_ti=1 if strpos(cond_desc, "clearing of lands") > 0 & d_add_green==0 & d_add_greening==0

*check which dirty sectors have incentives
tab isic_letter if d_dirty_polluting_ti==1

* create new variable for dirty sectors with incentive to incorporate the specific dirty  sectors (only find 241 to change)
gen     dirty_ti_sector=""

replace dirty_ti_sector=isic_letter if d_dirty_polluting_ti==1
replace dirty_ti_sector="241" if strpos(Isic_1letter, "C") > 0 & isic_sub_cond2=="only" &  ///
strpos(isic_3d, "241") > 0 & d_dirty_polluting_ti==1
replace dirty_ti_sector="241" if strpos(Isic_1letter, "Industrial") > 0 & isic_sub_cond2=="only" &  ///
strpos(isic_3d, "241") > 0 & d_dirty_polluting_ti==1


* check which dirty agricultural sectors have incentives - needs to be checked every time with updated completed country files (but these als have climate or green conditions so not applicable, leave here in any case)
replace dirty_ti_sector="stumping and clearing of land" if strpos(Isic_1letter, "A") > 0 &  ///
				strpos(cond_desc, "stumping" "clearing of lands") > 0  & d_dirty_polluting_ti==1
tab dirty_ti_sector


drop d_add_greening_* dirty_ti_sector

order d_add_green d_add_greening d_dirty_polluting_ti, after(sector_cond)

// Get the current date and format it as YYYYMMDD
local today = c(current_date)
local today_formatted = subinstr("`today'", " ", "", .)  // Remove spaces (default format is like "06 Sep 2024")
local today_formatted = subinstr("`today_formatted'", " ", "", .)  // Ensures no spaces in other date formats


// Save the file with the formatted date appended
 save "$edited_data/Clean GTI GTP Database - `today_formatted'.dta", replace
 export excel using "$edited_data/Clean GTI GTP Database - `today_formatted'.xlsx", firstrow(variables) replace

* capture log close
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	